==> Paws-0.43.tar.gz: Paws-0.43/lib/Paws/FraudDetector/UpdateVariable.pm <==

package Paws::FraudDetector::UpdateVariable;
  use Moose;
  has DefaultValue => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'defaultValue' );
  has Description => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'description' );
  has Name => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'name' , required => 1);
  has VariableType => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'variableType' );

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'UpdateVariable');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::FraudDetector::UpdateVariableResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::FraudDetector::UpdateVariable - Arguments for method UpdateVariable on L<Paws::FraudDetector>

=head1 DESCRIPTION

This class represents the parameters used for calling the method UpdateVariable on the
L<Amazon Fraud Detector|Paws::FraudDetector> service. Use the attributes of this class
as arguments to method UpdateVariable.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to UpdateVariable.

=head1 SYNOPSIS

    my $frauddetector = Paws->service('FraudDetector');
    my $UpdateVariableResult = $frauddetector->UpdateVariable(
      Name         => 'Mystring',
      DefaultValue => 'Mystring',    # OPTIONAL
      Description  => 'Mystring',    # OPTIONAL
      VariableType => 'Mystring',    # OPTIONAL
    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/frauddetector/UpdateVariable>

=head1 ATTRIBUTES


=head2 DefaultValue => Str

The new default value of the variable.



=head2 Description => Str

The new description.



=head2 B<REQUIRED> Name => Str

The name of the variable.



=head2 VariableType => Str

The variable type.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method UpdateVariable in L<Paws::FraudDetector>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.46.tar.gz: Paws-0.46/lib/Paws/FraudDetector/UpdateVariable.pm <==

package Paws::FraudDetector::UpdateVariable;
  use Moose;
  has DefaultValue => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'defaultValue' );
  has Description => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'description' );
  has Name => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'name' , required => 1);
  has VariableType => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'variableType' );

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'UpdateVariable');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::FraudDetector::UpdateVariableResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::FraudDetector::UpdateVariable - Arguments for method UpdateVariable on L<Paws::FraudDetector>

=head1 DESCRIPTION

This class represents the parameters used for calling the method UpdateVariable on the
L<Amazon Fraud Detector|Paws::FraudDetector> service. Use the attributes of this class
as arguments to method UpdateVariable.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to UpdateVariable.

=head1 SYNOPSIS

    my $frauddetector = Paws->service('FraudDetector');
    my $UpdateVariableResult = $frauddetector->UpdateVariable(
      Name         => 'Mystring',
      DefaultValue => 'Mystring',    # OPTIONAL
      Description  => 'Mystring',    # OPTIONAL
      VariableType => 'Mystring',    # OPTIONAL
    );

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/frauddetector/UpdateVariable>

=head1 ATTRIBUTES


=head2 DefaultValue => Str

The new default value of the variable.



=head2 Description => Str

The new description.



=head2 B<REQUIRED> Name => Str

The name of the variable.



=head2 VariableType => Str

The variable type. For more information see Variable types
(https://docs.aws.amazon.com/frauddetector/latest/ug/create-a-variable.html#variable-types).




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method UpdateVariable in L<Paws::FraudDetector>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
